"""Domain models - Value objects and entities."""

from gnosisllm_knowledge.core.domain.document import Document, DocumentStatus, TextChunk
from gnosisllm_knowledge.core.domain.result import (
    BatchResult,
    IndexResult,
    LoadResult,
    ValidationResult,
)
from gnosisllm_knowledge.core.domain.search import (
    AgenticSearchQuery,
    AgenticSearchResult,
    AgentType,
    ReasoningStep,
    SearchMode,
    SearchQuery,
    SearchResult,
    SearchResultItem,
)
from gnosisllm_knowledge.core.domain.source import SourceConfig

__all__ = [
    # Document
    "Document",
    "DocumentStatus",
    "TextChunk",
    # Result
    "LoadResult",
    "IndexResult",
    "BatchResult",
    "ValidationResult",
    # Search
    "SearchQuery",
    "SearchResult",
    "SearchResultItem",
    "SearchMode",
    "AgenticSearchQuery",
    "AgenticSearchResult",
    "AgentType",
    "ReasoningStep",
    # Source
    "SourceConfig",
]
