"""Interface definitions (protocols) for dependency injection."""

from gnosisllm_knowledge.core.interfaces.agentic import IAgenticSearcher
from gnosisllm_knowledge.core.interfaces.chunker import ITextChunker
from gnosisllm_knowledge.core.interfaces.fetcher import FetchResult, IContentFetcher
from gnosisllm_knowledge.core.interfaces.indexer import IDocumentIndexer
from gnosisllm_knowledge.core.interfaces.loader import IContentLoader
from gnosisllm_knowledge.core.interfaces.searcher import IKnowledgeSearcher
from gnosisllm_knowledge.core.interfaces.setup import ISetupAdapter

__all__ = [
    "IContentLoader",
    "IContentFetcher",
    "FetchResult",
    "ITextChunker",
    "IDocumentIndexer",
    "IKnowledgeSearcher",
    "IAgenticSearcher",
    "ISetupAdapter",
]
