"""Search backend implementations."""

from gnosisllm_knowledge.backends.memory import MemoryIndexer, MemorySearcher
from gnosisllm_knowledge.backends.opensearch import (
    AgenticSearchFallback,
    OpenSearchAgenticSearcher,
    OpenSearchConfig,
    OpenSearchIndexer,
    OpenSearchKnowledgeSearcher,
    OpenSearchSetupAdapter,
)
from gnosisllm_knowledge.backends.opensearch.queries import QueryBuilder

__all__ = [
    # OpenSearch
    "OpenSearchConfig",
    "OpenSearchIndexer",
    "OpenSearchKnowledgeSearcher",
    "OpenSearchSetupAdapter",
    "OpenSearchAgenticSearcher",
    "AgenticSearchFallback",
    "QueryBuilder",
    # Memory (for testing)
    "MemoryIndexer",
    "MemorySearcher",
]
